@@ -6,30 +6,30 @@ all.Amianhinfusionss<-function(){
      cat("-----------------------------------------------------------------------\n")                                                            
      cat("\n")
      note_for_close_window()
-     AmianhinfusionSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","R (mg/hr)","ts (hr)","c (mg/L)"),value=c(0))                                                                                                          
+     AmianhinfusionSSpar<-data.frame(parameter=c("Gender","age (yr)","ht (cm)","CHF","smoke","DL (mg)","tinf (hr)","Ro (mg/hr)","ts (hr)","c (mg/L)"),
+                                     value=c(0,65,187,1,1,400,24,15,36,8.71))
      AmianhinfusionSSpar<-edit(AmianhinfusionSSpar)                                                                                                                                                                                                             
 ##     AmianhinfusionSSpar<-ycheck(AmianhinfusionSSpar)     
      cat("\n")
+     cat("\n Input data are as follows:\n")
+     cat(" --------------------------\n")
+     show(AmianhinfusionSSpar);cat("\n\n")
      Amianhinfusion.ss(AmianhinfusionSSpar[10,2],AmianhinfusionSSpar[9,2],AmianhinfusionSSpar[3,2],AmianhinfusionSSpar[2,2],AmianhinfusionSSpar[5,2],AmianhinfusionSSpar[1,2],AmianhinfusionSSpar[4,2],AmianhinfusionSSpar[6,2],AmianhinfusionSSpar[8,2],AmianhinfusionSSpar[7,2])
      note_for_convergence_plots()
-     convergence_plots_sep()
-     cat("-----------------------------------------------------------------------\n")
-     cat("   --Aminophylline anhydrous iv infusion output data information--     \n")
+     ### convergence_plots_sep()
+     X <- read.table("params.csv",header=FALSE)
+     cl <- X[1,2]     
+     cat("---------------------------------------\n")
+     cat("             -- Output --              \n")
      note_for_Theinfusionss_output()
-     cat("-----------------------------------------------------------------------\n")
-     show(samplesStats("*"))                                                                                                                                                                                                            
+     cat("---------------------------------------\n")
+     ### show(samplesStats("*"))                                                                                                                                                                                                            
      cat("\n")
      C<-Theinfusioncpr(0.85,AmianhinfusionSSpar[6,2],AmianhinfusionSSpar[8,2],AmianhinfusionSSpar[9,2],AmianhinfusionSSpar[7,2])
-     sim<-matrix(C[1,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Cm_pr (mg/L)")    
-     coutput1<-coutput 
-     show(coutput)
-     C<-0.85*AmianhinfusionSSpar[8,2]/(samplesStats("cl"))
-     sim<-matrix(C[1,1])
-     coutput<-data.frame(sim)
-     colnames(coutput)<-list("Ctss_pr (mg/L)")  
-     coutput2<-coutput   
+     ### sim<-matrix(C[1,1])
+     C2<-0.85*AmianhinfusionSSpar[8,2]/(cl)
+     ## sim<-matrix(C[1,1])
+     coutput<-data.frame(conc=c("Cm_obs","Cm_pr","Css_pr"),value=c(AmianhinfusionSSpar[10,2],C,C2))
      show(coutput)
      cat("\n")   
      Amianhinfusion.more()          
