@@ -5,6 +5,10 @@ all.Digss<-function(){
      note_for_close_window()
      DigSSpar<-data.frame(parameter=c("Gender","age (yr)","bw (kg)","scr (mg/dL)","D (mg)","tau (hr)","c (ng/mL)"),value=c(0))
      DigSSpar<-edit(DigSSpar)
+     cat("\n")
+     cat("\n Input data are as follows:\n")
+     cat(" --------------------------\n")
+     show(DigSSpar);cat("\n\n")
 ##     DigSSpar<-ycheck(DigSSpar)
      cat("\n")
      Dig.ss(DigSSpar[7,2],DigSSpar[6,2],DigSSpar[5,2],DigSSpar[4,2],DigSSpar[3,2],DigSSpar[2,2],DigSSpar[1,2])
@@ -15,9 +19,7 @@ all.Digss<-function(){
      cat("\n") 
      C<-Digcpr(DigSSpar[5,2],DigSSpar[6,2])
      ### sim<-matrix(C[1 ,1])
-     coutput<-data.frame(C)
-     colnames(coutput)<-list("Cmss_pr (ng/mL)")
-     show(coutput)
-     cat("\n") 
+     coutput<-data.frame(Parameters=c("Cmss_obs (ng/mL)","Cmss_pr (ng/mL)"),Values=c(DigSSpar[7,2],C))
+     cat("\n\n");show(coutput);cat("\n") 
      Dig.more()
 }
\ No newline at end of file
