@@ -5,7 +5,7 @@ all.Litcitss<-function(){
      note_for_close_window()
      ### LitcitSSpar<-data.frame(parameter=c("age (yr)","bw (kg)","Scr (mg/dL)","D (mg)","tau (hr)","Css (mEq/L)"),value=c(0))
      LitcitSSpar<-data.frame(parameter=c("age (yr)","bw (kg)","Scr (mg/dL)","D (mg)","tau (hr)","Css (mEq/L)"),value=c(65,67,2.1,650,12,2.1))
-     ### LitcitSSpar<-edit(LitcitSSpar)            ### remarked this line for model testing.  --YJ
+     LitcitSSpar<-edit(LitcitSSpar)            ### remarked this line for model testing.  --YJ
      f<-ifelse(LitcitSSpar[1,2]>50,1.,0.)   ### 'LitSSpar[1,2]' = age; users save one more input in this case. great. -YJ
      cat("\n Input data are as follows:\n")
      cat(" --------------------------\n")
