@@ -52,14 +52,14 @@ note_for_infusionR_c_to_d <- function(){
      cat("  Css_trough = desired trough conc (mg/L)         \n")
      cat("                                                  \n")
      cat("  --output data--                                 \n")
-     cat("  R = intravenous infusion rate (mg/hr)  \n")
+     cat("  Ro = intravenous infusion rate (mg/hr)  \n")
      cat("--------------------------------------------------\n\n")
          }
          
 note_for_infusionR_d_to_c <- function(){
      cat("-------------------------------------------------\n")                                     
      cat("  --input data--                                 \n")
-     cat("  R = constant intravenous infusion rate (mg/hr) \n")
+     cat("  Ro = constant intravenous infusion rate (mg/hr) \n")
      cat("                                                 \n")
      cat("  --output data--                                \n")
      cat("  Css_trough = calculated trough conc (mg/L)      \n")
@@ -135,13 +135,13 @@ note_for_d_to_c_mcg <- function(){
  }
  
 note_for_c_to_d_meq <- function(){ 
-     cat("--------------------------------------------\n")
-     cat("  --input data--                            \n")
-     cat("  Css_trough = desired trough conc (mEq/L)  \n")
-     cat("  tau = desired dosing interval (hr)        \n")
-     cat("                                            \n")
-     cat("  --output data--                           \n")
-     cat("  Dose = calculated dose (mg)                \n")
+     cat("--------------------------------------------  \n")
+     cat("  --input data--                              \n")
+     cat("  Css_trough = desired trough conc (mEq/L)    \n")
+     cat("  tau = desired dosing interval (hr)        \n\n")
+     cat(" Lithium usual therapeutic range: 0.6-1.3 mEq/L\n\n")     
+     cat("  --output data--                             \n")
+     cat("  Dose = calculated dose (mg)                 \n")
      cat("--------------------------------------------\n\n")
  }
  
@@ -149,8 +149,8 @@ note_for_d_to_c_meq <- function(){
      cat("----------------------------------------------\n")
      cat("  --input data--                              \n")
      cat("  D = desired dose (mg)                       \n")
-     cat("  tau = desired dosing interval (hr)          \n")
-     cat("                                              \n")
+     cat("  tau = desired dosing interval (hr)        \n\n")
+     cat(" Lithium usual therapeutic range: 0.6-1.3 mEq/L\n\n")  
      cat("  --output data--                             \n")
      cat("  Css_trough = calculated trough conc (mEq/L)  \n")
      cat("----------------------------------------------\n\n")
@@ -159,18 +159,18 @@ note_for_d_to_c_meq <- function(){
 note_for_c_to_d_eno <- function(){ 
      cat("-----------------------------------------------------------------\n")
      cat("  --input data--                                                 \n")
-     cat("  Amax = desired anti-Xa maximal activity at stedy state (IU/mL) \n")
+     cat("  Amax = desired anti-Xa maximal activity at steady state (IU/mL) \n")
      cat("  tau = desired dosing interval (hr)                             \n")
      cat("                                                                 \n")
      cat("  --output data--                                                \n")
-     cat("  Dose = calculated dose (IU,1 mg = 100 IU)                       \n")
+     cat("  Dose = calculated dose (mg, 1 mg = 100 IU)                     \n")
      cat("-----------------------------------------------------------------\n\n")
  }
  
 note_for_d_to_c_eno <- function(){ 
      cat("--------------------------------------------------------------------\n")
      cat("  --input data--                                                    \n")
-     cat("  D = desired dose (IU,1mg=100IU)                                   \n")
+     cat("  D = desired dose (mg, 1 mg = 100IU)                               \n")
      cat("  tau = desired dosing interval (hr)                                \n")
      cat("                                                                    \n")
      cat("  --output data--                                                   \n")
@@ -178,27 +178,27 @@ note_for_d_to_c_eno <- function(){
      cat("--------------------------------------------------------------------\n\n")
  }
  
-note_for_c_to_d_war <- function(){ 
-     cat("--------------------------------------------------\n")
-     cat("  --input data--                                  \n")
-     cat("  INR = calculated international normalized ratio  \n")
-     cat("  tau = desired dosing interval (day)             \n")
-     cat("                                                  \n")
-     cat("  --output data--                                 \n")
-     cat("  Dose = desired/calculated dose (mg)              \n")
-     cat("--------------------------------------------------\n\n")
- }
- 
-note_for_d_to_c_war <- function(){ 
-     cat("--------------------------------------------------\n")
-     cat("  --input data--                                  \n")
-     cat("  D = desired dose (mg)                           \n")
-     cat("  tau = desired dosing interval (day)             \n")
-     cat("                                                  \n")
-     cat("  --output data--                                 \n")
-     cat("  INR = calculated international normalized ratio  \n")
-     cat("--------------------------------------------------\n\n")
- }
+### note_for_c_to_d_war <- function(){ 
+###      cat("--------------------------------------------------\n")
+###      cat("  --input data--                                  \n")
+###      cat("  INR = calculated international normalized ratio  \n")
+###      cat("  tau = desired dosing interval (day)             \n")
+###      cat("                                                  \n")
+###      cat("  --output data--                                 \n")
+###      cat("  Dose = desired/calculated dose (mg)              \n")
+###      cat("--------------------------------------------------\n\n")
+###  }
+###  
+### note_for_d_to_c_war <- function(){ 
+###      cat("--------------------------------------------------\n")
+###      cat("  --input data--                                  \n")
+###      cat("  D = desired dose (mg)                           \n")
+###      cat("  tau = desired dosing interval (day)             \n")
+###      cat("                                                  \n")
+###      cat("  --output data--                                 \n")
+###      cat("  INR = calculated international normalized ratio  \n")
+###      cat("--------------------------------------------------\n\n")
+###  }
     
 note_for_Amiss_input <- function(){
      cat("-------------------------------------------------------\n")
@@ -267,9 +267,9 @@ note_for_CBZss_input <- function(){
      cat("    PB = combine Phenobarbital(Y=1;N=0)                      \n")
      cat("    VPA = taking VPA and VPA daily dose >18 mg/kg(Y=1;N=0)   \n")
      cat("    PHT = combine Phenytoin(Yes=1;No=0)                      \n")
-     cat("    E = age more than 65yr(Y=1;N=0)                          \n")
-     cat("    D = dose for each dosing interval(mg)                    \n")
-     cat("    tau = dosing interval(hr)                                \n")
+     cat("    E = age older than 65yr(Y=1;N=0)                         \n")
+     cat("    D = dose for each dosing interval(mg) (200-600 mg q12h)  \n")
+     cat("    tau = dosing interval(hr)(q12h or q24h)                  \n")
      cat("    ts = sampling time(hr)                                   \n")
      cat("    c = measured steady-state conc.(mg/L)                    \n")
      cat("-------------------------------------------------------------\n")
@@ -278,10 +278,10 @@ note_for_CBZss_input <- function(){
 note_for_CBZss_output <- function(){
      cat("-----------------------------------------------------------------\n")
      cat("    --Carbamazepine output data information--                    \n")
-     cat("    cl = estimated clearance/bioavailability (L/hr)               \n")
-     cat("    v = estimated volume of distribution/bioavailability (L)     \n")
-     cat("    Cmss_pr = calculated steady-state conc.(mg/L)        \n")
-     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)          \n")
+     cat("    cl_F = estimated clearance/bioavailability (L/hr)            \n")
+     cat("    v_F = estimated volume of distribution/bioavailability (L)   \n")
+     cat("    Cmss_pr = calculated steady-state conc.(mg/L)                \n")
+     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)         \n")
      cat("-----------------------------------------------------------------\n")
 }
 
@@ -292,9 +292,9 @@ note_for_CBZsm_input <- function(){
      cat("    PB = combine Phenobarbital(Y=1;N=0)                       \n")
      cat("    VPA = taking VPA and VPA daily dose >18 mg/kg(Y=1;N=0)    \n")
      cat("    PHT = combine Phenytoin(Y=1;N=0)                          \n")
-     cat("    E = age more than 65yr(Y=1;N=0)                           \n")
-     cat("    D = dose for each dosing interval(mg)                     \n")
-     cat("    tau = dosing interval(hr)                                 \n")
+     cat("    E = age older than 65yr(Y=1;N=0)                          \n")
+     cat("    D = dose for each dosing interval(mg) (200-600 mg q12h)   \n")
+     cat("    tau = dosing interval(hr)(q12h or q24h)                   \n")
      cat("--------------------------------------------------------------\n")
 }
 
@@ -309,7 +309,7 @@ note_for_CBZsm_conc_input <- function(){
 note_for_CBZsm_output <- function(){
      cat("------------------------------------------------------------------\n")
      cat("    --Carbamazepine output data information--                     \n")
-     cat("    cl_F = estimated clearance/bioavailability (L/hr)              \n")
+     cat("    cl_F = estimated clearance/bioavailability (L/hr)             \n")
      cat("    V_F = estimated volume of distribution/bioavailability (L)    \n")
      cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)          \n")
      cat("------------------------------------------------------------------\n")
@@ -342,20 +342,21 @@ note_for_Lit_input <- function(){
      cat("-----------------------------------------------------\n")
      cat("    --Lithium carbonate input data information--     \n")
      cat("    age = age (yr)                                   \n") 
-     cat("    f = age<50 (Y=0,N=1)                             \n") 
+     ## cat("    f = age<50 (Y=0,N=1)                             \n") 
      cat("    bw = body weight(kg)                             \n")
      cat("    Scr = serum creatinine conc (mg/dL)              \n")   
      cat("    D = dose for each dosing interval(mg)            \n")
      cat("    tau = dosing interval(hr)                        \n")
-     cat("    c = measured steady-state conc.(mEq/L)           \n")  
+     cat("    Css = measured steady-state conc.(mEq/L)           \n")  
      cat("-----------------------------------------------------\n")
 }
 
 note_for_Lit_output <- function(){
      cat("--------------------------------------------------------------\n")
      cat("    --Lithium carbonate output data information--             \n")
-     cat("    cl_F = estimated clearance/bioavailability (L/hr)          \n")
-     cat("    Cmss_pr = calculated steady-state conc.(mEq/L)            \n")
+     cat("    cl_F = estimated clearance/bioavailability (L/hr)         \n")
+     cat("    Cmss_pr = calculated steady-state conc.(mEq/L)          \n\n")
+     cat(" Lithium usual therapeutic range: 0.6-1.3 mEq/L               \n")
      cat("--------------------------------------------------------------\n")
 }
 
@@ -364,7 +365,7 @@ note_for_Litcit_input <- function(){
      cat("----------------------------------------------------\n")
      cat("    --Lithium citrate input data information--      \n")
      cat("    age = age (yr)                                  \n") 
-     cat("    f = age<50 (Y=0,N=1)                            \n") 
+     ## cat("    f = age<50 (Y=0,N=1)                            \n") 
      cat("    bw = body weight(kg)                            \n")
      cat("    Scr = serum creatinine conc (mg/dL)             \n")   
      cat("    D = dose for each dosing interval(mg)           \n")
@@ -377,7 +378,8 @@ note_for_Litcit_output <- function(){
      cat("--------------------------------------------------------------\n") 
      cat("    --Lithium citrate output data information--               \n")
      cat("    cl_F = estimated clearance/bioavailability (L/hr)          \n")
-     cat("    Cmss_pr = calculated steady-state conc.(mEq/L)            \n")
+     cat("    Cmss_pr = calculated steady-state conc.(mEq/L)          \n\n")
+     cat(" Lithium usual therapeutic range: 0.6-1.3 mEq/L               \n")
      cat("--------------------------------------------------------------\n") 
 }
 
@@ -409,45 +411,45 @@ note_for_Eno_input <- function(){
      cat("    Gender = 1 for Male ; 0 for Female                        \n") 
      cat("    TBW = body weight(kg)                                     \n")   
      cat("    Scr = serum creatinine conc.(mg/dL)                       \n")
-     cat("    D = dose for each dosing interval(IU); 1mg = 100 IU       \n")
-     cat("    tau = dosing interval(hr)                                 \n")
-     cat("    Amax = anti-Xa maximal activity at stedy state (IU/mL)    \n")
+     cat("    D = dose (mg) for each dosing interval; (1mg = 100 IU)    \n")
+     cat("    tau = dosing interval(hr); (usually 12 hr)                \n")
+     cat("    Amax = anti-Xa maximal activity at steady state (IU/mL)   \n")
      cat("--------------------------------------------------------------\n") 
 }
 
 note_for_Eno_output <- function(){
-     cat("-----------------------------------------------------------------------------\n") 
-     cat("    --Enoxaparin output data information--                                   \n")
-     cat("    cl_F = estimated clearance/bioavailability (L/hr)                         \n")
-     cat("    v_F = estimated volume of distribution/bioavailability (L)               \n")
-     cat("    Amaxss_pr = calculated anti-Xa maximal activity at stedy state (IU/mL)    \n")
-     cat("-----------------------------------------------------------------------------\n") 
+     cat("-------------------------------------------------------------------------\n") 
+     cat(" --Enoxaparin output data information--                                   \n")
+     cat("  cl_F = estimated clearance/bioavailability (L/hr)                        \n")
+     cat("  v_F = estimated volume of distribution/bioavailability (L)               \n")
+     cat("  Amaxss_pr = calculated anti-Xa maximal activity at steady state (IU/mL)  \n")
+     cat("--------------------------------------------------------------------------\n") 
 }
 
 
 
-note_for_War_input <- function(){
-     cat("--------------------------------------------------\n")
-     cat("    --Warfarin input data information--           \n")
-     cat("    D = dose for each dosing interval(mg)         \n")
-     cat("    tau = dosing interval(day)                    \n")
-     cat("    INR = international normalized ratio          \n")
-     cat("--------------------------------------------------\n") 
-}
-
-note_for_War_output <- function(){
-     cat("-----------------------------------------------------------------\n") 
-     cat("  --Warfarin output data information--                           \n")
-     cat("  Cpmax = estimated concentration related with maximum           \n")
-     cat("          suppression of clotting factors (mg/L)                 \n")
-     cat("  cl_F = estimated clearance/bioavailability (L/day)              \n")
-     cat("  kc = estimated first order rate constant for clotting          \n")
-     cat("       factor degradation (1/day)                                \n")
-     cat("  m = estiamted prothrombin complex activity remaining (%/day)   \n")
-     cat("  v_F = estimated volume of distribution/bioavailability (L)     \n")
-     cat("  INR = calculated international normalized ratio                 \n")
-     cat("-----------------------------------------------------------------\n") 
-}
+### note_for_War_input <- function(){
+###      cat("--------------------------------------------------\n")
+###      cat("    --Warfarin input data information--           \n")
+###      cat("    D = dose for each dosing interval(mg)         \n")
+###      cat("    tau = dosing interval(day)                    \n")
+###      cat("    INR = international normalized ratio          \n")
+###      cat("--------------------------------------------------\n") 
+### }
+### 
+### note_for_War_output <- function(){
+###      cat("-----------------------------------------------------------------\n") 
+###      cat("  --Warfarin output data information--                           \n")
+###      cat("  Cpmax = estimated concentration related with maximum           \n")
+###      cat("          suppression of clotting factors (mg/L)                 \n")
+###      cat("  cl_F = estimated clearance/bioavailability (L/day)              \n")
+###      cat("  kc = estimated first order rate constant for clotting          \n")
+###      cat("       factor degradation (1/day)                                \n")
+###      cat("  m = estiamted prothrombin complex activity remaining (%/day)   \n")
+###      cat("  v_F = estimated volume of distribution/bioavailability (L)     \n")
+###      cat("  INR = calculated international normalized ratio                 \n")
+###      cat("-----------------------------------------------------------------\n") 
+### }
 
 
 
@@ -457,7 +459,7 @@ note_for_Valss_input <- function(){
      cat("    age = age (yr)                                              \n")   
      cat("    INDI(indication)=1 for uncontrolled epilepsy, otherwise 0   \n")
      cat("    CBZ = combine CArbamazepine (Y=1, N=0)                      \n")
-     cat("    ka = 4 for oral solution, 1 for enteric tablet              \n")
+     ### cat("    ka = 4 for oral solution, 1 for enteric tablet              \n")
      cat("    D = dose for each dosing interval(mg)                       \n") 
      cat("    tau = dosing interval(hr)                                   \n")
      cat("    ts = sampling time (hr)                                     \n") 
@@ -465,12 +467,14 @@ note_for_Valss_input <- function(){
      cat("----------------------------------------------------------------\n")
 }
 
-note_for_Valss_output <- function(){
+note_for_Valss_output <- function(ts){
      cat("--------------------------------------------------------------\n")
      cat("    --Valpraote output data information--                     \n")
-     cat("    cl = estimated clearance (L/hr)                            \n")
-     cat("    Cmss_pr = calculated steady-state conc.(mg/L)     \n")
-     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)       \n")
+     cat("    cl_F = estimated clearance (L/hr)                         \n")
+     cat("     v_F = estimated volume of distribution (L)               \n")
+     cat("      ka = absorption rate constant (/hr)                     \n")
+     cat("    Cmss_pr = calculated steady-state conc.(mg/L) at time =",ts,"\n")
+     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)      \n")
      cat("--------------------------------------------------------------\n")
 }
 
@@ -480,7 +484,7 @@ note_for_Valsm_input <- function(){
      cat("    age = age (yr)                                               \n")   
      cat("    CBZ = combine the use of carbamazepine (Yes=1, No=0)         \n")
      cat("    INDI(indication)=1 for uncontrolled epilepsy, otherwise 0    \n")
-     cat("    ka = 4 for oral solution, 1 for enteric tablet               \n")
+     ### cat("    ka = 4 for oral solution, 1 for enteric tablet           \n")
      cat("    tau = dosing interval(hr)                                    \n")
      cat("    D = dose for each dosing interval(mg)                        \n") 
      cat("-----------------------------------------------------------------\n")
@@ -489,7 +493,7 @@ note_for_Valsm_input <- function(){
 note_for_Valsm_conc_input <- function(){
      cat("--------------------------------------------------\n")
      cat("    --Valpraote input data information--          \n")
-     cat("    c = measured steady-state conc.(mg/L)         \n")
+     cat("    c = measured steady-state conc.(mg/L) at 'ts' \n")
      cat("    ts = sampling time (hr)                       \n") 
      cat("--------------------------------------------------\n")
 }
@@ -497,8 +501,10 @@ note_for_Valsm_conc_input <- function(){
 note_for_Valsm_output <- function(){
      cat("--------------------------------------------------------------\n")
      cat("    --Valpraote output data information--                     \n")
-     cat("    cl = estimated clearance (L/hr)                            \n")
-     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)       \n")
+     cat("    cl_F = estimated clearance (L/hr)                         \n")
+     cat("     v_F = estimated volume of distribution (L)               \n")
+     cat("      ka = absorption rate constant (/hr)                     \n")
+     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)      \n")
      cat("--------------------------------------------------------------\n")
 }
 
@@ -717,28 +723,28 @@ note_for_Indsm_output <- function(){
 note_for_Ritss_input <- function(){
      cat("-------------------------------------------------\n")
      cat("    --Ritonavir input data information--         \n")
-     cat("    LPv = combine Lopinavir (Y=1;N=0)            \n")
+     cat("    LPV = combine with Lopinavir? (Y=1;N=0)      \n")
      cat("    D = dose for each dosing interval(mg)        \n")
      cat("    tau = dosing interval(hr)                    \n")
      cat("    ts = sampling time(hr)                       \n")
-     cat("    c = measured steady-stat conc.(mg/L)         \n")    
+     cat("    c = measured steady-stat conc.(mcg/L)        \n")    
      cat("-------------------------------------------------\n")
 }
 
 note_for_Ritss_output <- function(){
      cat("-------------------------------------------------------------------\n")
      cat("    --Ritonavir output data information--                          \n")
-     cat("    cl_F = estimated clearance/bioavailability (L/hr)               \n")
+     cat("    cl_F = estimated clearance/bioavailability (L/hr)              \n")
      cat("    v_F = estimated volume of distribution/bioavailability (L)     \n")
-     cat("    Cmss_pr = calculated steady-state measured conc.(mg/L)          \n")
-     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)            \n")
+     cat("    Cmss_pr = calculated steady-state measured conc.(mcg/L)        \n")
+     cat("    Ctss_pr = calculated steady-state trough conc.(mcg/L)          \n")
      cat("-------------------------------------------------------------------\n")
 }
 
 note_for_Ritsm_input <- function(){
      cat("--------------------------------------------------\n")
      cat("    --Ritonavir input data information--          \n")
-     cat("    LPV = combine Lopinavir (Y=1;N=0)             \n")
+     cat("    LPV = combine with Lopinavir? (Y=1;N=0)       \n")
      cat("    D = dose for each dosing interval(mg)         \n")
      cat("    tau = dosing interval(hr)                     \n")
      cat("--------------------------------------------------\n")
@@ -747,7 +753,7 @@ note_for_Ritsm_input <- function(){
 note_for_Ritsm_conc_input <- function(){
      cat("------------------------------------------------\n")
      cat("    --Ritonavir input data information--        \n")
-     cat("    c = measured steady-stat conc.(mg/L)        \n")
+     cat("    c = measured steady-stat conc.(mcg/L)        \n")
      cat("    ts = sampling time(hr)                      \n")
      cat("------------------------------------------------\n")
 }
@@ -757,7 +763,7 @@ note_for_Ritsm_output <- function(){
      cat("    --Ritonavir output data information--                         \n")
      cat("    cl_F = estimated clearance/bioavailability (L/hr)              \n")
      cat("    v_F = estimated volume of distribution/bioavailability (L)    \n")
-     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)           \n")
+     cat("    Ctss_pr = calculated steady-state trough conc.(mcg/L)           \n")
      cat("------------------------------------------------------------------\n")
 }
 
@@ -779,9 +785,10 @@ note_for_Cycss_input <- function(){
 note_for_Cycss_output <- function(){
      cat("-------------------------------------------------------------\n")
      cat("   --Cyclosporine output data information--                  \n")
-     cat("   cl = estimated clearance (L/hr)                            \n")
-     cat("   Cmss_pr = calculated steady-state conc.(mcg/L)    \n")
-     cat("   Ctss_pr = calculated steady-state trough conc.(mcg/L)      \n")
+     cat("   cl = estimated clearance (L/hr)                           \n")
+     cat("   Cmss_pr = calculated steady-state (SS) conc.(mcg/L) at ts \n")
+     cat("   C(2)_pr = calculated SS conc.(mcg/L) at time = 2 hr       \n")
+     cat("   Ctss_pr = calculated SS trough conc.(mcg/L)               \n")
      cat("-------------------------------------------------------------\n")
 }
 
@@ -873,8 +880,8 @@ note_for_Tacss_input <- function(){
      cat("    --Tacrolimus input data information--             \n")
      cat("    Hem = 0 for hematocrit < 30% , otherwise 1        \n")   
      cat("    Alb = 0 for albumin < 3.5g/dL , otherwise 1       \n") 
-     cat("    Dil = combine Diltiazem(Y=1, N=0)                 \n")
-     cat("    Flu = combine Fluconazole(Y=1, N=0)               \n")
+     cat("    Dil = combine with Diltiazem? (Yes=1, No=0)       \n")
+     cat("    Flu = combine with Fluconazole? (Yes=1, No=0)     \n")
      cat("    D = dose for each dosing interval(mg)             \n")
      cat("    tau = dosing interval(hr)                         \n")
      cat("    ts = sampling time(hr)                            \n")  
@@ -884,11 +891,11 @@ note_for_Tacss_input <- function(){
 
 note_for_Tacss_output <- function(){
      cat("--------------------------------------------------------------------\n")
-     cat("    --Tacrolimus output data information--                          \n")
-     cat("    cl_F = estimated clearance/bioavailability (L/hr)                \n")
-     cat("    v_F = estimated volume of distribution/bioavailability (L)      \n")
-     cat("    Cmss_pr = calculated steady-state conc.(mcg/mL)         \n")
-     cat("    Ctss_pr = calculated steady-state trough conc.(mcg/mL)           \n")
+     cat("    --Tacrolimus output data information--                         \n")
+     cat("    cl_F = estimated clearance/bioavailability (L/hr)              \n")
+     ### cat("    v_F = estimated volume of distribution/bioavailability (L)     \n")   ### no 'v_F' with tacrolimus. -YJ
+     cat("    Cmss_pr = calculated steady-state conc.(mcg/mL) at time of ts  \n")
+     cat("    Ctss_pr = calculated steady-state trough conc.(mcg/mL)         \n")
      cat("--------------------------------------------------------------------\n")
 }
 
@@ -897,8 +904,8 @@ note_for_Tacsm_input <- function(){
      cat("    --Tacrolimus input data information--            \n")
      cat("    Hem = 0 for hematocrit < 30% , otherwise 1       \n")   
      cat("    Alb = 0 for albumin < 3.5 g/dL , otherwise 1     \n") 
-     cat("    Dil = combine Diltiazem(Y=1, N=0)                \n")
-     cat("    Flu = combine Fluconazole(Y=1, N=0)              \n")
+     cat("    Dil = combine with Diltiazem? (Yes=1, No=0)      \n")
+     cat("    Flu = combine with Fluconazole? (Yes=1, No=0)    \n")
      cat("    D = dose for each dosing interval(mg)            \n")
      cat("    tau = dosing interval(hr)                        \n")
      cat("-----------------------------------------------------\n")
@@ -916,7 +923,7 @@ note_for_Tacsm_output <- function(){
      cat("-------------------------------------------------------------------\n")
      cat("    --Tacrolimus output data information--                         \n")
      cat("    cl_F = estimated clearance/bioavailability (L/hr)               \n")
-     cat("    v_F = estimated volume of distribution/bioavailability (L)     \n")
+     ### cat("    v_F = estimated volume of distribution/bioavailability (L)     \n")   ### no 'v_F' with tacrolimus. -YJ
      cat("    Ctss_pr = calculated steady-state trough conc.(mcg/mL)          \n")
      cat("-------------------------------------------------------------------\n")
 }
@@ -927,14 +934,20 @@ note_for_Imass_input <- function(){
      cat("------------------------------------------------------\n")
      cat("    --Imatinib mesylate input data information--      \n")
      cat("    BW = body weight(kg)                              \n")
-     cat("    OCC = 0 for day 1 and 1 for day 29                \n")
+     cat("    OCC = dichotomous covariate for time (two occasions)\n")
+     cat("        = 0 for day 1 and 1 for day 29                \n")
      cat("    Hb = Hemoglobin (g/dL)                            \n")
      cat("    WBC = white blood count (10^9/L)                  \n")
      cat("    n = dosing number                                 \n") 
      cat("    D = dose for each dosing interval(mg)             \n") 
      cat("    tau = dosing interval(hr)                         \n")
      cat("    ts = sampling time (hr)                           \n")
-     cat("    c = measured conc.(mg/L)                          \n")
+     cat("    c = measured conc.(mg/L)                        \n\n")
+     cat("ref.:Schmidli, H., B. Peng, et al. (2005). Population  \n")
+     cat("    pharmacokinetics of imatinib mesylate in patients  \n")
+     cat("    with chronic-phase chronic myeloid leukaemia:      \n")
+     cat("    results of a phase III study. Br J Clin Pharmacol  \n")
+     cat("    60(1): 35-44.                                      \n")
      cat("------------------------------------------------------\n")
 }
 
@@ -952,12 +965,18 @@ note_for_Imasm_input <- function(){
      cat("-------------------------------------------------------\n")
      cat("    --Imatinib mesylate input data information--       \n")
      cat("    BW = body weight(kg)                               \n")
-     cat("    OCC = 0 for day 1 and 1 for day 29                 \n")
+     cat("    OCC = dichotomous covariate for time (two occasions)\n")
+     cat("        = 0 for day 1 and 1 for day 29                 \n")
      cat("    Hb = Hemoglobin (g/dL)                             \n")
      cat("    WBC = white blood count (10^9/L)                   \n")
      cat("    n = dosing number                                  \n") 
      cat("    D = dose for each dosing interval(mg)              \n") 
-     cat("    tau = dosing interval(hr)                          \n")
+     cat("    tau = dosing interval(hr)                        \n\n")
+     cat("ref.:Schmidli, H., B. Peng, et al. (2005). Population  \n")
+     cat("    pharmacokinetics of imatinib mesylate in patients  \n")
+     cat("    with chronic-phase chronic myeloid leukaemia:      \n")
+     cat("    results of a phase III study. Br J Clin Pharmacol  \n")
+     cat("    60(1): 35-44.                                      \n")
      cat("-------------------------------------------------------\n")
 }
 
@@ -992,11 +1011,12 @@ note_for_Theirss_input <- function(){
 }
 
 note_for_Theirss_output <- function(){
-     cat("    cl_F = estimated clearance/bioavailability (L/hr)              \n")
+     cat("    cl_F = estimated clearance/bioavailability (L/hr)             \n")
      cat("    v_F = estimated volume of distribution/bioavailability (L)    \n")
-     cat("    Cmss_pr = calculated steady-state measured conc.(mg/L)         \n")
-     cat("    Cpss_pr = calculated steady-state peak conc.(mg/L)             \n")
-     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)           \n")
+     cat("    Cmss_obs = the steady-state measured conc.(mg/L)              \n")
+     cat("    Cmss_pr = calculated steady-state measured conc.(mg/L)        \n")
+     cat("    Cpss_pr = calculated steady-state peak conc.(mg/L)            \n")
+     cat("    Ctss_pr = calculated steady-state trough conc.(mg/L)          \n")
 }
 
 note_for_Theirsm_input <- function(){
@@ -1045,32 +1065,32 @@ note_for_Theinfusionss_input <- function(){
      cat("    smoke = 1 for a amoker ; otherwise 0                   \n") 
      cat("    DL = loading dose (mg)                                 \n")
      cat("    tinf = infusion time of loading dose (hr)              \n") 
-     cat("    R = constant intravenous infusion rate (mg/hr)         \n") 
+     cat("    Ro = constant intravenous infusion rate (mg/hr)         \n") 
      cat("    ts = sampling time since infusion end (hr)             \n")
-     cat("    C = measured conc. (mg/L)                             \n")
+     cat("    C = measured conc. (mg/L)                              \n")
 }
 
 note_for_Theinfusionss_output <- function(){
-     cat("   cl = estimated clearance (L/hr)                                    \n")
-     cat("   v = estimated volume of distribution (L)                          \n")
-     cat("   Cm_pr = calculated plasma conc.(mg/L)                            \n")
-     cat("   Ctss_pr = calculated steady-state trough conc.(mg/L)               \n")
+     cat("   cl = estimated clearance (L/hr)                         \n")
+     cat("   Cm_obs = obs. theo plasma conc.(mg/L)                   \n")
+     cat("   Cm_pr  = calculated theo plasma conc.(mg/L)             \n")
+     cat("   Css_pr = calculated theo steady-state conc.(mg/L)       \n")
 }
 
 note_for_Theinfusionsm_input <- function(){
-     cat("    Gender = Male=1 ; Female=0                             \n")
-     cat("    age = age (yr)                                         \n")
-     cat("    ht = height (cm)                                       \n") 
-     cat("    CHF = 1 for yes ; otherwise = 0                        \n")
-     cat("    smoke = 1 for a amoker ; otherwise 0                   \n") 
-     cat("    DL = loading dose (mg)                                 \n")
-     cat("    tinf = infusion time of loading dose (hr)              \n") 
-     cat("    R = constant intravenous infusion rate (mg/hr)         \n") 
+     cat("   Gender = Male=1 ; Female=0                             \n")
+     cat("   age = age (yr)                                         \n")
+     cat("   ht = height (cm)                                       \n") 
+     cat("   CHF = 1 for yes ; otherwise = 0                        \n")
+     cat("   smoke = 1 for a amoker ; otherwise 0                   \n") 
+     cat("   DL = loading dose (mg)                                 \n")
+     cat("   tinf = infusion time of loading dose (hr)              \n") 
+     cat("   Ro = constant intravenous infusion rate (mg/hr)        \n") 
 }
 
 note_for_Theinfusionsm_output <- function(){
-     cat("   cl = estimated clearance (L/hr)                                    \n")
-     cat("   v = estimated volume of distribution (L)                          \n")
-     cat("   Ctss_pr = calculated steady-state trough conc.(mg/L)               \n")
+     cat("   cl = estimated clearance (L/hr)                         \n")
+     cat("    v = estimated volume of distribution (L)               \n")
+     cat("   Css_pr = calculated steady-state conc.(mg/L)            \n")
 }
 
